MmlFaceSdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • MmlFaceSdkPlatform
Implementers

Constructors

MmlFaceSdkPlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createTemplate(Uint8List image) → Future<Map<Object?, Object?>>
createTemplateFrame(Uint8List nv21, int width, int height, int rotationDegrees) → Future<Map<Object?, Object?>>
dispose() → Future<void>
getDeviceBinding() → Future<Map<Object?, Object?>>
hasModelPack(String version) → Future<bool>
installModelPack(String version, Map<String, Uint8List> models) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetLiveness() → Future<void>
toString() → String
A string representation of this object.
inherited
verify(Uint8List image, List<double> template, {required bool liveness}) → Future<Map<Object?, Object?>>
Ensures that the platform instance was constructed with a non-const token that matches the provided token and throws AssertionError if not.
override
verifyFrame(Uint8List nv21, int width, int height, int rotationDegrees, List<double> template, {required bool liveness}) → Future<Map<Object?, Object?>>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ MmlFaceSdkPlatform
getter/setter pair